/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.components;

import java.awt.Color;
import java.awt.Toolkit;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.net.URL;

import javax.swing.JTextField;
import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;
import javax.swing.text.Document;
import javax.swing.text.PlainDocument;

import net.sf.dc.console.dialogs.MessageBox;
import net.sf.ext.jflexsett.settings.ui.ISettingsComponent;
import net.sf.ext.util.BrowserLauncher;

/**
 * Simple field, derived from JTextField, which allows
 * URLs to be opened
 *
 * @author Robert-Jan van der Waals
 * @since 1.3
 * @version 0.90
 */
public class URLField extends JTextField implements ISettingsComponent {

    int MAX_TEXT_LENGTH = 0;

    protected class URLFieldDocument extends PlainDocument {
        public void insertString(int i, String s, AttributeSet attributeset)
            throws BadLocationException {

            if (i + 1 > MAX_TEXT_LENGTH) {
                toolkit.beep();
            } else {
                super.insertString(i, s, attributeset);
            }
        }
    }

    private Toolkit toolkit;

    /**
     * Creates this field
     * @param maxTextLength the maximum text length
     */
    public URLField(int maxTextLength) {
        super();
        setForeground(new Color(120,120,255));
        this.addMouseListener(new OpenUrlAction());
        MAX_TEXT_LENGTH = maxTextLength;
        toolkit = Toolkit.getDefaultToolkit();
    }

    protected Document createDefaultModel() {
        return new URLFieldDocument();
    }

    public Object getValue() {
        return getText();
    }

    public void setValue(Object o) {
        setText(o.toString());
    }

    /**
     * Opens an url. Works for every platform
     * @see BrowserLauncher
     */
    private class OpenUrlAction implements MouseListener {
        public void mouseReleased(MouseEvent e) {
            if (e.getClickCount() == 2) {
                try {
                    String sURL = getText();
                    
                    if (!sURL.toUpperCase().startsWith("HTTP://")) {
                        sURL = "http://" + sURL;
                    }

                    URL url = new URL(sURL);
                    BrowserLauncher.openURL(url.toString());
                } catch (Exception exp) {
                	new MessageBox(exp.getMessage(), MessageBox._ERROR);
                }
            }
        }
        public void mouseEntered(MouseEvent e) {}
        public void mouseExited(MouseEvent e) {}
        public void mousePressed(MouseEvent e) {}
        public void mouseClicked(MouseEvent e) {
        }
    }
}
