/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.musicfile.organizer;

import java.awt.Color;
import java.awt.GridBagConstraints;
import java.awt.Insets;
import java.io.File;

import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;

import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.console.components.FileField;
import net.sf.dc.console.components.Layout;
import net.sf.dc.console.dialogs.MessageBox;
import net.sf.dc.core.Repository;
import net.sf.dc.processes.MusicFilesOrganizerTask;
import net.sf.dc.resources.DCLabels;
import net.sf.dc.resources.DCTooltips;
import net.sf.ext.jflexsett.settings.Settings;
import net.sf.ext.util.Resources;

/**
 * @author Robert Jan van der Waals
 * @since 1.4
 * @version 1.5
 */
public class MusicFileMoverPanel extends MusicFileOrganizerBasePanel {

    private MusicFilesOrganizerTask process;
    
    private final Color color = 
        Settings.getValueAsColor(Repository.settings.stColor);

    private final FileField fieldOutput = new FileField(false, true);
    private final FileField fieldInput = new FileField(false, true);
    //private final JCheckBox checkMove = ComponentFactory.getCheckBox(
    //                         Resources.getText(DCLabels.lblMoveFiles));
    
    private final JComboBox combo1;
    private final JComboBox combo2;
    private final JComboBox combo3;
    
    private final String[] sortBy = {
            "",
            Resources.getText(DCLabels.lblGenre),
            Resources.getText(DCLabels.lblAlbum),
            Resources.getText(DCLabels.lblArtist)};
    
    public MusicFileMoverPanel() {
        combo1 = getStructureCombo();
        combo2 = getStructureCombo();
        combo3 = getStructureCombo();
        
        buildPanel();
    }
    
    protected void start(MusicFileOrganizerDialog ui) {
        this.ui = ui;
        try {
            String[] sSortBy = null;

            if (combo1.getSelectedIndex() < 1) {
                new MessageBox( "Please select ordering type",
                                MessageBox._INFORMATION);
                return;
            } else {
                sSortBy = new String[1];
                sSortBy[0] = combo1.getSelectedItem().toString();
            }
            String sInputDirectory = fieldInput.getFileAsString() + File.separator;
            String sOutputDirectory = fieldOutput.getFileAsString() + File.separator;
            File fileIn = new File(sInputDirectory);

            if (!fileIn.exists() || !fileIn.isDirectory()) {
                new MessageBox("Please select a valid input / output directory",
                               MessageBox._INFORMATION);
                return;
            }

            process = new MusicFilesOrganizerTask(this,
                                                 sSortBy,
                                                 sInputDirectory,
                                                 sOutputDirectory);
            process.start();

        } catch (Exception exp) {
            updateLog("Error occured;" + '\n' + exp.toString());
        }        
    }
    

    protected void cancel() {
        if (process != null) {
        	process.stopRunning();
        }
        finish(); 
    }      
    
    private void buildPanel() {
    	setBackground(color);
        setLayout(Layout.getGBL());
        
        JPanel panelInput = createInputPanel();
        //JPanel panelSort = createSortPanel();
        JPanel logPanel = createLogPanel();
        JPanel progressPanel = createProgressPanel();        
        
        add(panelInput,     Layout.getGBC( 0, 0, 1, 1, 1.0, 1.0
                           ,GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                            new Insets(5, 5, 5, 5), 0, 0));
        //add(panelSort,      Layout.getGBC( 0, 1, 1, 1, 1.0, 1.0
          //                 ,GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
            //                new Insets(5, 5, 5, 5), 0, 0)); 
        add(logPanel,       Layout.getGBC( 0, 3, 1, 1, 40.0, 40.0
                           ,GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
                            new Insets(5, 5, 5, 5), 0, 0));
        add(progressPanel,  Layout.getGBC( 0, 4, 1, 1, 1.0, 1.0
                           ,GridBagConstraints.SOUTHWEST, GridBagConstraints.HORIZONTAL,
                            new Insets(5, 5, 5, 5), 0, 0));        
    }
    
    /**
     * Creates the main panel
     */
    private JPanel createInputPanel() {
        JPanel inputPanel = new JPanel(false);
        inputPanel.setBackground(color);
        
        JLabel labelOutput = ComponentFactory.getLabel(
                Resources.getText(DCLabels.lblOutputDirectory));
        JLabel labelInput = ComponentFactory.getLabel(
                Resources.getText(DCLabels.lblInputDirectory));
        labelOutput.setToolTipText(
                Resources.getText(DCTooltips.tpInputDirNotSelected));
        JLabel labelSorting = ComponentFactory.getLabel(
                Resources.getText(DCLabels.lblDirectoryStructure));
        
        inputPanel.setLayout(Layout.getGBL());
        inputPanel.add(labelInput, Layout.getGBC( 0, 0, 1, 1, 1.0, 1.0
                      ,GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                       new Insets(0, 0, 0, 0), 0, 0));
        inputPanel.add(fieldInput, Layout.getGBC( 1, 0, 1, 1, 1.0, 1.0
                      ,GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                       new Insets(0, 0, 0, 0), 0, 0));
        inputPanel.add(labelOutput, Layout.getGBC( 0, 1, 1, 1, 1.0, 1.0
                      ,GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                       new Insets(0, 0, 0, 0), 0, 0));
        inputPanel.add(fieldOutput, Layout.getGBC( 1, 1, 1, 1, 1.0, 1.0
                      ,GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                       new Insets(0, 0, 0, 0), 0, 0));
        inputPanel.add(labelSorting,Layout.getGBC( 0, 2, 1, 1, 1.0, 1.0
                      ,GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                       new Insets(0, 0, 0, 0), 0, 0));
        inputPanel.add(combo1,      Layout.getGBC( 1, 2, 1, 1, 1.0, 1.0
                      ,GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                       new Insets(0, 0, 0, 0), 0, 0));

        return inputPanel;
    }
    
/*    private JPanel createSortPanel() {
        JPanel panelSort = new JPanel(false);
        panelSort.setLayout(Layout.getGBL());
        panelSort.setBackground(color);
        
        JLabel labelSorting = ComponentFactory.getLabel(
                Resources.getText(DCLabels.lblDirectoryStructure));
        
        panelSort.add(labelSorting, 
                      Layout.getGBC( 0, 0, 1, 1, 1.0, 1.0
                     ,GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                      new Insets(0, 0, 0, 0), 0, 0));
        panelSort.add(combo1, Layout.getGBC( 1, 0, 1, 1, 1.0, 1.0
                     ,GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                      new Insets(0, 0, 0, 0), 0, 0));
        panelSort.add(combo2, Layout.getGBC( 2, 0, 1, 1, 1.0, 1.0
                     ,GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                      new Insets(0, 0, 0, 0), 0, 0));
        panelSort.add(combo3, Layout.getGBC( 3, 0, 1, 1, 1.0, 1.0
                     ,GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                      new Insets(0, 0, 0, 0), 0, 0)); 
        
        return panelSort;
    } */
    
    private JComboBox getStructureCombo() {
        JComboBox combo = ComponentFactory.getComboBox();
        for (int i = 0; i < sortBy.length ; i++) {
            combo.addItem(sortBy[i]);
        }
        combo.setSelectedIndex(0);
        return combo;
    }    
}
