/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.core.modules;

import javax.swing.ImageIcon;
import javax.swing.JMenu;

import net.sf.dc.console.DCMenuBar;
import net.sf.dc.console.audiocd.InsertAudioTrackPanel;
import net.sf.dc.console.audiocd.SearchAudioTrackPanel;
import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.console.da.ImportCDDialog;
import net.sf.dc.core.IconLibrary;
import net.sf.dc.core.Repository;
import net.sf.dc.core.objects.DCFieldDefinition;
import net.sf.dc.core.objects.DCObject;
import net.sf.dc.core.objects.audiocd.AudioTrack;
import net.sf.dc.processes.cdimport.ImportCDProcess;
import net.sf.dc.resources.DCLabels;
import net.sf.ext.util.Resources;

/**
 * The Audio Track module
 * @see net.sf.dc.core.modules.DCModules
 * @see net.sf.dc.core.modules.DCModule
 * 
 * @author Robert-Jan van der Waals
 * @since 1.4
 * @version 1.50
 */
public class AudioTrackModule extends DCModule {
    
    private final DCMenuBar menuBar = null;
    
    /**
     * Initializes this module
     */
    public AudioTrackModule() {
        super(DCModules._AUDIOTRACK,
              Resources.getText(DCLabels.lblModuleAudioCD),
              "audiotracks",
              "autr",
              "audiotracks",
              false,
              false);
    }

    public String getObjectName() {
        return Resources.getText(DCLabels.lblAudioTrack);
    }
    
    public ImageIcon getIcon() {
        return IconLibrary._icoExisting;
    }
    
    public DCMenuBar getMenuBar() {
        return menuBar;
    }    
    
    public JMenu getToolsMenu() {
        return null;
    }
    
    /**
     * Return the object managed by this module 
     * @see AudioTrack
     */
    public DCObject getDCObject() {
        return new AudioTrack();
    }
    
    public void startImport() {
    }
    
        
    /**
     * Create the insert and search panel
     */
    protected void initializeUI() {
        insertPanel = new InsertAudioTrackPanel();
     	searchPanel = new SearchAudioTrackPanel();
    }
        
    public String getHiddenFieldsSettingsKey() {
        return Repository.settings.stHiddenFieldsAudioTrack;
    }

    public String getRequiredFieldsSettingsKey() {
        return Repository.settings.stAudioTrackRequiredFields;
    }
    
    public ImportCDProcess getCDImportProcess(ImportCDDialog ui,
                                              String sourceDir,
                                              boolean confirmEachDir,
                                              String nameOfCD) {
        return null;
    }
    
    /**
     * Initalizes all the fields
     */
    protected void initializeFields() {
        fields = new DCFieldDefinition[6];
        fields[AudioTrack._ID] = new DCFieldDefinition(Resources.getText(DCLabels.lblID),
                                        true,
                                        false,
                                        false,
                                        15,
                                        ComponentFactory._SHORTTEXTFIELD,
                                        Repository.datatypes._STRING,
                                        "ID");
        fields[AudioTrack._A_TRACKNUMBER] = new DCFieldDefinition(Resources.getText(DCLabels.lblTrackNumber),
                                        false,
                                        false,
                                        false,
                                        255,
                                        ComponentFactory._NUMBERFIELD,
                                        Repository.datatypes._INTEGER,
                                        "Track");
        fields[AudioTrack._B_TITLE] = new DCFieldDefinition(Resources.getText(DCLabels.lblTrackTitle),
                                        false,
                                        true,
                                        false,
                                        8000,
                                        ComponentFactory._SHORTTEXTFIELD,
                                        Repository.datatypes._STRING,
                                        "Title");
        fields[AudioTrack._C_LYRICS] = new DCFieldDefinition(Resources.getText(DCLabels.lblLyric),
                                        false,
                                        true,
                                        false,
                                        255,
                                        ComponentFactory._LONGTEXTFIELD,
                                        Repository.datatypes._STRING,
                                        "Lyric");                                       
        fields[AudioTrack._D_PLAYLENGTH] = new DCFieldDefinition(Resources.getText(DCLabels.lblTrackPlaylength),
                                        false,
                                        false,
                                        false,
                                        255,
                                        ComponentFactory._TIMEFIELD,
                                        Repository.datatypes._INTEGER,
                                        "PlayLength");
        fields[AudioTrack._E_ALBUM] = new DCFieldDefinition(Resources.getText(DCLabels.lblAlbum),
                                        true,
                                        false,
                                        false,
                                        255,
                                        ComponentFactory._SHORTTEXTFIELD,
                                        Repository.datatypes._PARENTREFERENCE,
                                        "Album");                                     
    }
    
    public DCObject[] getDefaultData() {
        return new DCObject[0];
    }
}
