/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.ext.util.archiver;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Enumeration;
import java.util.ResourceBundle;
import java.util.Vector;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import java.util.zip.ZipOutputStream;

import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.core.Repository;
import net.sf.dc.resources.DCLabels;
import net.sf.dc.resources.DCMessages;
import net.sf.dc.resources.DCRIFFAudioCodecs;
import net.sf.dc.resources.DCTooltips;
import net.sf.dc.settings.SettingInitializator;
import net.sf.ext.jflexsett.settings.Settings;
import net.sf.ext.util.DirectoryReader;
import net.sf.ext.util.ModularResourceBundle;
import net.sf.ext.util.Resources;


public class Archiver {
    
    private final String backupDir = "." +  File.separator + "backup" + File.separator;
    private final String backupExt = ".zip";
    
    public static void main(String[] args) {
        
        Resources.addTextResourceBundle((ModularResourceBundle) ResourceBundle.getBundle(DCTooltips.class.getName()));
        Resources.addTextResourceBundle((ModularResourceBundle) ResourceBundle.getBundle(DCLabels.class.getName()));
        Resources.addTextResourceBundle((ModularResourceBundle) ResourceBundle.getBundle(DCMessages.class.getName()));
        Resources.addTextResourceBundle((ModularResourceBundle) ResourceBundle.getBundle(DCRIFFAudioCodecs.class.getName()));
        new SettingInitializator();        
        new ComponentFactory();
        
        Archiver archiver = new Archiver();
        archiver.createBackup("test");
        System.out.print(archiver.listContent("test"));
        archiver.restoreBackup("test");
    }
    
    private String listContent(String zipFile) {
        StringBuffer sb = new StringBuffer();
        try {
            File file = new File(backupDir + zipFile + backupExt);
            String outputFile = file.getAbsolutePath();
            
            ZipFile zf = new ZipFile(outputFile);
        
            for (Enumeration entries = zf.entries(); entries.hasMoreElements();) {
                sb.append(((ZipEntry) entries.nextElement()).getName());
                sb.append("\r\n");
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
        return sb.toString();
    }
    
    private void restoreBackup(String zipFile) {
        try {
            // Open the ZIP file
            File file = new File(backupDir + zipFile + backupExt);
            String outputFile = file.getAbsolutePath();
            ZipFile zf = new ZipFile(outputFile);
        
            for (Enumeration entries = zf.entries(); entries.hasMoreElements();) {
                ZipEntry entry = (ZipEntry) entries.nextElement();
                InputStream in = zf.getInputStream(entry);
                FileOutputStream out = new FileOutputStream(entry.getName());
                
                byte[] buf = new byte[1024];
                int len;
                while ((len = in.read(buf)) > 0) {
                    out.write(buf, 0, len);
                }
                out.flush();
                out.close();
                in.close();
            }            
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
    
    
    private void createBackup(String outputName) {
        String databasename = Settings.getValueAsString(Repository.settings.stConnectionString);
        
        Vector vFiles = new Vector();
        try {
            String dir = "." + File.separator + "data";
        	vFiles = DirectoryReader.read(dir, false, true, false, null, false);
        } catch (Exception exp) {
        }
        
        byte[] buf = new byte[1024];
        
        File flTemp = new File(backupDir);
        if (!flTemp.exists()) {
            flTemp.mkdir();
        }
        
        try {
            File file = new File(backupDir + outputName + backupExt);
            String outputFile = file.getAbsolutePath();
            
            ZipOutputStream out = new ZipOutputStream(new FileOutputStream(outputFile));
        
            for (Enumeration enum = vFiles.elements(); enum.hasMoreElements(); ) {
                String sFile = enum.nextElement().toString();
                
                FileInputStream in = new FileInputStream(sFile);
        
                out.putNextEntry(new ZipEntry(sFile));
        
                int len;
                while ((len = in.read(buf)) > 0) {
                    out.write(buf, 0, len);
                }
        
                out.closeEntry();
                in.close();
            }
        
            out.flush();
            out.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}
